#
# spec file for package perl-Net-Netmask
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Net-Netmask
Name:           perl-Net-Netmask
Version:        2.0002
Release:        1.8
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Understand and manipulate IP netmasks
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/J/JM/JMASLAK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Math::BigInt) >= 1.999811
BuildRequires:  perl(Test2::V0) >= 0.000111
BuildRequires:  perl(Test::UseAllModules) >= 0.17
Requires:       perl(Math::BigInt) >= 1.999811
Recommends:     perl(AnyEvent) >= 7.14
%{perl_requires}

%description
Net::Netmask parses and understands IPv4 and IPv6 CIDR blocks (see
https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing for more
information on CIDR blocks). It's built with an object-oriented interface,
with functions being methods that operate on a Net::Netmask object.

These methods provide nearly all types of information about a network block
that you might want.

There are also functions to insert a network block into a table and then
later lookup network blocks by IP address using that table. There are
functions to turn a IP address range into a list of CIDR blocks. There are
functions to turn a list of CIDR blocks into a list of IP addresses.

There is a function for sorting by text IP address.

All functions understand both IPv4 and IPv6. Matches, finds, etc, will
always return false when an IPv4 address is matched against an IPv6
address.

IPv6 support was added in 1.9104.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CODE_OF_CONDUCT.md CONTRIBUTING errors.err README TODO
%license LICENSE

%changelog
* Thu Sep  1 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.0002
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
  2.0002 2022-08-31
  - Documentation fixes (thanks, Breno G. de Oliveira!)
* Tue Mar 30 2021 Tina Müller <tina.mueller@suse.com>
- Remove manual license from cpanspec.yml, the correct one is now
  specified upstream
* Tue Mar 30 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.0001
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
* Sun Jul 29 2018 coolo@suse.com
- updated to 1.9104
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
* Tue Jun 19 2018 coolo@suse.com
- updated to 1.9103
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
  1.9103 2018-06-18
  - Use ASCII-like regex matching (Github #4)
  - Convert tests to Test2
  - Pass perlcritic tests
  - Pass Kwalitee tests
  - Add contributor information
  - Add protocol() method (just a stub today that will always return
    'IPv4')
  1.9102 2018-06-18
  - DEV release only
  - Contains most changes that made it to 1.9103.
* Wed Jun  6 2018 coolo@suse.com
- updated to 1.9101
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
* Tue May  5 2015 coolo@suse.com
- updated to 1.9022
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
  1.9022 2015-05-05
  - Changes from adamherzog: minor cleanups plus
  - A bunch of addtional tests
  - A couple of small code fixes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.9021
  see /usr/share/doc/packages/perl-Net-Netmask/Changes
  1.9021 2014-07-17
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.9019
  - Rename $b to $bits so that netmask can be sorted.  Change mostly
    from https://rt.cpan.org/Ticket/Display.html?id=76939
  - Minor MANIFEST fix.
  - Add network split() function.
  - Re-arrange the distribution a bit.
* Tue Mar 27 2012 cfarrell@suse.com
- license update: Artistic-1.0 or GPL-1.0+
  Package is licensed under the same terms as Perl
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Thu Mar 24 2011 vcizek@novell.com
- update to 1.9016
  Fix bug rt#46996: warnings issued for bad input.
  Fix bug rt#43348: use POSIX::floor() instead of int()
  Rewrite netmask.t to use Test::More
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Dec 13 2006 anicka@suse.cz
- update to 1.9015
  * Fix bug: cidrs2inverse wouldn't notice /32-sized leftovers.
* Thu Oct 19 2006 anicka@suse.cz
- update to 1.9014
  * Fix bug: cidrs2inverse wouldn't notice /32-sized holes.
* Thu Sep 14 2006 anicka@suse.cz
- update to 1.9013
  * Added the nextblock() method
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.9012
* Thu Aug 19 2004 mjancar@suse.cz
- update to 1.9011
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.9007
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Thu Jun 19 2003 mjancar@suse.cz
- update to 1.9004
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Jan 15 2002 rvasice@suse.cz
- update to version 1.9002
* Tue Aug 14 2001 rvasice@suse.cz
- update to version 1.9
* Mon Mar 26 2001 cihlar@suse.cz
- added make test
* Tue Nov 14 2000 cihlar@suse.cz
- renamed perl_nm -> perl-Net-Netmask
* Thu Aug 24 2000 cihlar@suse.cz
- update to version 1.8
- added BuildRoot
- bzipped sources
* Fri Jan 21 2000 ro@suse.de
- fixed filelist
* Mon Nov  8 1999 choeger@suse.de
- first version
